@@ -23,11 +23,13 @@ ignore "Test1" = ""
 ignore "Test3"
 ignore "Test2" = ignoreTest
 warn = ignoreTest3
+suggest = ignoreTest4
 ignore = Ignore_Test
 
 {-# ANN module "HLint: ignore Test4" #-}
 {-# ANN annTest2 "HLint: error" #-}
 {-# ANN annTest3 ("HLint: warn" :: String) #-}
+{-# ANN annTest4 ("HLint: suggest" :: String) #-}
 {-# ANN type Ann_Test ("HLint: ignore") #-}
 
 
@@ -63,6 +65,7 @@ yes = before 12 -- after 12
 ignoreTest = filter -- @Ignore ???
 ignoreTest2 = filter -- @Error ???
 ignoreTest3 = filter -- @Warning ???
+ignoreTest4 = filter -- @Suggestion ???
 ignoreAny = scanr -- @Ignore ???
 ignoreNew = foldr -- @Ignore ???
 type Ignore_Test = Int -- @Ignore ???
@@ -70,6 +73,7 @@ type Ignore_Test = Int -- @Ignore ???
 annTest = foldl -- @Ignore ???
 annTest2 = foldl -- @Error ???
 annTest3 = scanr -- @Warning ???
+annTest4 = scanr -- @Suggestion ???
 type Ann_Test = Int -- @Ignore ???
 
 concatMap f x = concat (map f x)
