@@ -263,9 +263,6 @@ showSrcLoc (SrcLoc file line col) = take 1 file ++ f (drop 1 file) ++ ":" ++ sho
           f (x:xs) = x : f xs
           f [] = []
 
-toSrcLoc :: SrcSpanInfo -> SrcLoc
-toSrcLoc = getPointLoc
-
 toSrcSpan :: SrcSpanInfo -> SrcSpan
 toSrcSpan (SrcSpanInfo x _) = x
 
