@@ -59,10 +59,16 @@ deriving instance Functor Bar
 deriving instance Show Bar -- {-# LANGUAGE StandaloneDeriving #-}
 {-# LANGUAGE DeriveGeneric, GeneralizedNewtypeDeriving #-} \
 newtype Micro = Micro Int deriving Generic -- {-# LANGUAGE DeriveGeneric #-}
+{-# LANGUAGE GeneralizedNewtypeDeriving #-} \
+instance Class Int where {newtype MyIO a = MyIO a deriving NewClass}
 {-# LANGUAGE UnboxedTuples #-} \
 f :: Int -> (# Int, Int #)
 {-# LANGUAGE UnboxedTuples #-} \
 f :: x -> (x, x); f x = (x, x) --
+{-# LANGUAGE DefaultSignatures #-} \
+class Val a where; val :: a --
+{-# LANGUAGE DefaultSignatures #-} \
+class Val a where; val :: a; default val :: Int
 </TEST>
 -}
 
@@ -76,7 +82,7 @@ import Refact.Types
 
 
 extensionsHint :: ModuHint
-extensionsHint _ x = [rawIdea Error "Unused LANGUAGE pragma" (toSrcSpan sl)
+extensionsHint _ x = [rawIdea Warning "Unused LANGUAGE pragma" (toSrcSpan sl)
           (prettyPrint o) (Just newPragma)
           (warnings old new) [refact]
     | not $ used TemplateHaskell x -- if TH is on, can use all other extensions programmatically
@@ -138,6 +144,7 @@ used UnboxedTuples = has (not . isBoxed)
 used PackageImports = hasS (isJust . importPkg)
 used QuasiQuotes = hasS isQuasiQuote
 used ViewPatterns = hasS isPViewPat
+used DefaultSignatures = hasS isClsDefSig
 used DeriveDataTypeable = hasDerive ["Data","Typeable"]
 used DeriveFunctor = hasDerive ["Functor"]
 used DeriveFoldable = hasDerive ["Foldable"]
@@ -167,16 +174,21 @@ hasDerive want m = any (`elem` want) $ new ++ dat
 -- | What is derived on newtype, and on data type
 --   'deriving' declarations may be on either, so we approximate as both newtype and data
 derives :: Module_ -> ([String],[String])
-derives = concatUnzip . map f . childrenBi
+derives m = concatUnzip $ map decl (childrenBi m) ++ map idecl (childrenBi m)
     where
-        f :: Decl_ -> ([String], [String])
-        f (DataDecl _ dn _ _ _ ds) = g dn ds
-        f (GDataDecl _ dn _ _ _ _ ds) = g dn ds
-        f (DataInsDecl _ dn _ _ ds) = g dn ds
-        f (GDataInsDecl _ dn _ _ _ ds) = g dn ds
-        f (DerivDecl _ _ hd) = (xs, xs) -- don't know whether this was on newtype or not
+        idecl :: InstDecl S -> ([String], [String])
+        idecl (InsData _ dn _ _ ds) = g dn ds
+        idecl (InsGData _ dn _ _ _ ds) = g dn ds
+        idecl _ = ([], [])
+
+        decl :: Decl_ -> ([String], [String])
+        decl (DataDecl _ dn _ _ _ ds) = g dn ds
+        decl (GDataDecl _ dn _ _ _ _ ds) = g dn ds
+        decl (DataInsDecl _ dn _ _ ds) = g dn ds
+        decl (GDataInsDecl _ dn _ _ _ ds) = g dn ds
+        decl (DerivDecl _ _ hd) = (xs, xs) -- don't know whether this was on newtype or not
             where xs = [ir hd]
-        f _ = ([], [])
+        decl _ = ([], [])
 
         g dn ds = if isNewType dn then (xs,[]) else ([],xs)
             where xs = maybe [] (map ir . fromDeriving) ds
