@@ -1,7 +1,7 @@
 
-module Main where
+module Main(main) where
 
-import Language.Haskell.HLint
+import Language.Haskell.HLint3
 import Control.Monad
 import System.Environment
 import System.Exit
